@@ -111,12 +111,10 @@ typedef enum {
 
 /**
  * babl_space_from_icc:
- *
  * @icc_data: pointer to icc profile in memory
  * @icc_length: length of icc profile in bytes
  * @intent: the intent from the ICC profile to use.
- *
- " @error: pointer to a string where decoding errors can be stored,
+ * @error: (out): pointer to a string where decoding errors can be stored,
  *         if an error occurs, NULL is returned and an error message
  *         is provided in error.
  *
@@ -136,7 +134,14 @@ const Babl *babl_space_from_icc (const char       *icc_data,
                                  int               icc_length,
                                  BablIccIntent     intent,
                                  const char      **error);
-
+/* babl_space_get_gamma:
+ * @space: a babl space
+ * 
+ * Returns the gamma of the TRCs of the space, iff they are all equal
+ * and a simple gamma number, otherwise 0.0 is returned.
+ */
+double
+babl_space_get_gamma (const Babl *space);
 
 // XXX : deprecated
 const Babl *babl_icc_make_space (const char       *icc_data,
@@ -153,17 +158,17 @@ const Babl *babl_icc_make_space (const char       *icc_data,
  * @language: 2 char code for language to extract or NULL
  * @country: 2 char country code or NULL
  *
- * Returns NULL if key not found or a malloc allocated utf8 string of the key
- * when found, free with free() when done. Supported keys: "description",
- * "copyright", "manufacturer", "device", "profile-class", "color-space" and
- * "pcs".
+ * Returns: (transfer full) (nullable): %NULL if key not found or a newly
+ * allocated utf8 string of the key when found, free with free() when done.
+ * Supported keys: "description", "copyright", "manufacturer", "device",
+ * "profile-class", "color-space" and "pcs".
  */
 
 char *babl_icc_get_key (const char *icc_data,
                         int         icc_length,
                         const char *key,
                         const char *language,
-                        const char *counter);
+                        const char *country);
 
 
 /**
@@ -285,8 +290,21 @@ const Babl * babl_format_get_model             (const Babl *format);
 
 
 
-
-enum _BablModelFlag
+/**
+ * BablModelFlag
+ * @BABL_MODEL_FLAG_ALPHA:  the model encodes alpha.
+ * @BABL_MODEL_FLAG_ASSOCIATED: the alpha is associated alpha.
+ * @BABL_MODEL_FLAG_INVERTED: the components are inverted (used for getting the additive complement space of CMYK).
+ * @BABL_MODEL_FLAG_LINEAR: the data has no TRC, i.e. is linear
+ * @BABL_MODEL_FLAG_NONLINEAR: the data has a TRC - the TRC from the configured space
+ * @BABL_MODEL_FLAG_PERCEPTUAL: the data has a TRC - a perceptual TRC where 50% gray is 0.5
+ * @BABL_MODEL_FLAG_GRAY: this is a gray component model
+ * @BABL_MODEL_FLAG_RGB: this is an RGB based component model, the space associated is expected to contain an RGB matrix profile.
+ * @BABL_MODEL_FLAG_CIE: this model is part of the CIE family of spaces
+ * @BABL_MODEL_FLAG_CMYK: the encodings described are CMYK encodings, the space associated is expected to contain an CMYK ICC profile.
+ *
+ */
+typedef enum
 {
   BABL_MODEL_FLAG_ALPHA         = 1<<1,
   BABL_MODEL_FLAG_ASSOCIATED    = 1<<2,
@@ -302,13 +320,11 @@ enum _BablModelFlag
   BABL_MODEL_FLAG_CIE           = 1<<23,
   BABL_MODEL_FLAG_CMYK          = 1<<24,
   /* BABL_MODEL_FLAG_LUZ        = 1<<25, NYI */
-};
+} BablModelFlag;
 
 // XXX : should warn when used
 #define BABL_MODEL_FLAG_PREMULTIPLIED BABL_MODEL_FLAG_ASSOCIATED
 
-typedef enum _BablModelFlag BablModelFlag;
-
 /* linear, nonlinear and perceptual could occupy two bits with a decidated 0,
  * but we do not have a lack of bits in this bit pattern so leave it be.
  */
@@ -479,6 +495,10 @@ int   babl_format_is_palette   (const Babl *format);
 
 /**
  * babl_palette_set_palette:
+ * @babl: a #Babl
+ * @format: The pixel format
+ * @data: (array) (element-type guint8): The pixel data
+ * @count: The number of pixels in @data
  *
  * Assign a palette to a palette format, the data is a single span of pixels
  * representing the colors of the palette.
@@ -520,7 +540,22 @@ typedef enum {
 } BablSpaceFlags;
 
 /**
- * babl_space_from_chromaticities
+ * babl_space_from_chromaticities:
+ * @name: (nullable): The name for the color space
+ * @wx: The X-coordinate of the color space's white point
+ * @wy: The Y-coordinate of the color space's white point
+ * @rx: The X-coordinate of the red primary
+ * @ry: The Y-coordinate of the red primary
+ * @gx: The X-coordinate of the green primary
+ * @gy: The Y-coordinate of the green primary
+ * @bx: The X-coordinate of the blue primary
+ * @by: The Y-coordinate of the blue primary
+ * @trc_red: The red component of the TRC.
+ * @trc_green: (nullable): The green component of the TRC (can be %NULL if it's
+ *            the same as @trc_red).
+ * @trc_blue: (nullable): The blue component of the TRC (can be %NULL if it's
+ *            the same as @trc_red).
+ * @flags: The #BablSpaceFlags
  *
  * Creates a new babl-space/ RGB matrix color space definition with the
  * specified CIE xy(Y) values for white point: wx, wy and primary
@@ -566,9 +601,23 @@ const Babl *babl_space_with_trc (const Babl *space, const Babl *trc);
 
 /**
  * babl_space_get:
+ * @space: A #Babl instance
+ * @xw: (out) (optional): The X-coordinate of the color space's white point
+ * @yw: (out) (optional): The Y-coordinate of the color space's white point
+ * @xr: (out) (optional): The X-coordinate of the red primary
+ * @yr: (out) (optional): The Y-coordinate of the red primary
+ * @xg: (out) (optional): The X-coordinate of the blue primary
+ * @yg: (out) (optional): The Y-coordinate of the green primary
+ * @xb: (out) (optional): The X-coordinate of the blue primary
+ * @yb: (out) (optional): The Y-coordinate of the blue primary
+ * @red_trc: (out) (optional): The red component of the TRC.
+ * @green_trc: (out) (optional): The green component of the TRC (can be %NULL
+ *             if it's the same as @red_trc).
+ * @blue_trc: (out) (optional): The blue component of the TRC (can be %NULL if
+ *            it's the same as @red_trc).
  *
  * query the chromaticities of white point and primaries as well as trcs
- * used for r g a nd b, all arguments mights be NULL.
+ * used for r g a nd b, all arguments are optional (can be %NULL).
  */
 void babl_space_get (const Babl *space,
                      double *xw, double *yw,
@@ -582,9 +631,9 @@ void babl_space_get (const Babl *space,
 /**
  * babl_space_get_rgb_luminance:
  * @space: a BablSpace
- * @red_luminance: pointer to a double where red luminance factor is stored
- * @green_luminance: pointer to a double where green luminance factor is stored
- * @blue_luminance: pointer to a double where blue luminance factor is stored
+ * @red_luminance: (out) (optional): Location for the red luminance factor.
+ * @green_luminance: (out) (optional): Location for the green luminance factor.
+ * @blue_luminance: (out) (optional): Location for the blue luminance factor.
  *
  * Retrieve the relevant RGB luminance constants for a babl space.
  */
@@ -597,8 +646,8 @@ babl_space_get_rgb_luminance (const Babl *space,
 /**
  * babl_model_is:
  *
- * return 0 if the name of the model in babl does not correspond to the provided
- * model name.
+ * Returns: 0 if the name of the model in babl does not correspond to the
+ * provided model name.
  */
 int babl_model_is (const Babl *babl, const char *model_name);
 
@@ -607,21 +656,38 @@ int babl_model_is (const Babl *babl, const char *model_name);
 
 /**
  * babl_space_get_icc:
+ * @babl: a #Babl
+ * @length: (out) (optional): Length of the profile in bytes.
  *
  * Return pointer to ICC profile for space note that this is
  * the ICC profile for R'G'B', though in formats only supporting linear
  * like EXR GEGL chooses to load this lienar data as RGB and use the sRGB
  * TRC.
  *
- * @babl: a BablSpace
- * @length: point to an integer where length of profile in bytes is stored.
- *
- * Returns pointer to ICC profile data.
+ * Returns: pointer to ICC profile data.
  */
 const char *babl_space_get_icc (const Babl *babl, int *length);
 
 /**
  * babl_space_from_rgbxyz_matrix:
+ * @name: (nullable): The name for the color space
+ * @wx: The X-coordinate of the color space's white point
+ * @wy: The Y-coordinate of the color space's white point
+ * @wz: The Z-coordinate of the color space's white point
+ * @rx: The X-coordinate of the red primary
+ * @ry: The Y-coordinate of the red primary
+ * @rz: The Z-coordinate of the red primary
+ * @gx: The X-coordinate of the green primary
+ * @gy: The Y-coordinate of the green primary
+ * @gz: The Z-coordinate of the green primary
+ * @bx: The X-coordinate of the blue primary
+ * @by: The Y-coordinate of the blue primary
+ * @bz: The Z-coordinate of the blue primary
+ * @trc_red: The red component of the TRC.
+ * @trc_green: (nullable): The green component of the TRC (can be %NULL if it's
+ *            the same as @trc_red).
+ * @trc_blue: (nullable): The blue component of the TRC (can be %NULL if it's
+ *            the same as @trc_red).
  *
  * Creates a new RGB matrix color space definition using a precomputed D50
  * adapted 3x3 matrix and associated CIE XYZ whitepoint, as possibly read from
@@ -645,6 +711,7 @@ babl_space_from_rgbxyz_matrix (const char *name,
 const char * babl_format_get_encoding (const Babl *babl);
 
 int babl_space_is_cmyk (const Babl *space);
+int babl_space_is_gray (const Babl *space);
 
 /* values below this are stored associated with this value, it should also be
  * used as a generic alpha zero epsilon in GEGL to keep the threshold effects
